@@ -2,7 +2,7 @@ package Yars::Command::yars_disk_scan;
 
 # PODNAME: yars_disk_scan
 # ABSTRACT: scan a disk for corruption and report corrupt files to stdout
-our $VERSION = '1.23'; # VERSION
+our $VERSION = '1.24'; # VERSION
 
 
 use strict;
@@ -18,7 +18,7 @@ use Pod::Usage qw( pod2usage );
 use Fcntl ':flock';
 
 sub main {
-    #my $class = shift;
+    my $class = shift;
     my $status = 0;
     my $conf = Clustericious::Config->new("Yars");
     my $opt_all = 0;
