@@ -2,7 +2,7 @@ package Yars::Command::yars_fast_balance;
 
 # PODNAME: yars_fast_balance
 # ABSTRACT: Fix all files
-our $VERSION = '1.23'; # VERSION
+our $VERSION = '1.24'; # VERSION
 
 
 use strict;
@@ -125,7 +125,8 @@ sub check_disk {
 }
 
 sub main {
-    local @_ = @ARGV;
+    my $class = shift;
+    local @ARGV = @_;
     GetOptions(
         'help|h'  => sub { pod2usage({ -verbose => 2}) },
         'version' => sub {
